@@ -8,7 +8,7 @@ package Devel::MAT::SV;
 use strict;
 use warnings;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -295,15 +295,15 @@ The referrant SV itself.
 sub _outrefs_matching
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    # In scalar context we're just counting so we might as well count just SVs
-   $just_svs ||= !wantarray;
+   $no_desc ||= !wantarray;
 
-   my @outrefs = $self->_outrefs( $match, $just_svs );
+   my @outrefs = $self->_outrefs( $match, $no_desc );
 
    if( $match & STRENGTH_WEAK and my $blessed = $self->blessed ) {
-      push @outrefs, $just_svs ? $blessed :
+      push @outrefs, $no_desc ? ( weak => $blessed ) :
          Reference( "the bless package", weak => $blessed );
    }
 
@@ -313,17 +313,19 @@ sub _outrefs_matching
       if( my $obj = $self->df->sv_at( $obj_at ) ) {
          my $is_strong = ( $flags & 0x01 );
          if( $match & ( $is_strong ? STRENGTH_STRONG : STRENGTH_WEAK ) ) {
-            push @outrefs, $just_svs ? $obj :
-               Reference( "'$type' magic object", ( $is_strong ? "strong" : "weak" ) => $obj );
+            my $strength = $is_strong ? "strong" : "weak";
+            push @outrefs, $no_desc ? ( $strength => $obj ) :
+               Reference( "'$type' magic object", $strength => $obj );
          }
       }
 
       if( $match & STRENGTH_STRONG and my $ptr = $self->df->sv_at( $ptr_at ) ) {
-         push @outrefs, $just_svs ? $ptr :
+         push @outrefs, $no_desc ? ( strong => $ptr ) :
             Reference( "'$type' magic pointer", strong => $ptr );
       }
    }
 
+   return @outrefs / 2 if !wantarray;
    return @outrefs;
 }
 
@@ -387,7 +389,7 @@ boolean true and false. They are
 
 package Devel::MAT::SV::Immortal;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 use constant immortal => 1;
 sub new {
    my $class = shift;
@@ -400,13 +402,13 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::UNDEF;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
 package Devel::MAT::SV::YES;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 sub desc { "YES" }
 sub type { "SCALAR" }
 
@@ -421,7 +423,7 @@ sub name {}
 
 package Devel::MAT::SV::NO;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 sub desc { "NO" }
 sub type { "SCALAR" }
 
@@ -436,7 +438,7 @@ sub name {}
 
 package Devel::MAT::SV::Unknown;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 0xff );
 
 sub desc { "UNKNOWN" }
@@ -445,7 +447,7 @@ sub _outrefs {}
 
 package Devel::MAT::SV::GLOB;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 1 );
 use constant $CONSTANTS;
 
@@ -581,14 +583,14 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my @outrefs;
 
    if( $match & STRENGTH_STRONG ) {
       foreach my $slot (qw( scalar array hash code io form )) {
          my $sv = $self->$slot or next;
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( "the $slot", strong => $sv );
       }
    }
@@ -598,8 +600,9 @@ sub _outrefs
       my $egv_is_self = $egv == $self;
 
       if( $match & ( $egv_is_self ? STRENGTH_WEAK : STRENGTH_STRONG ) ) {
-         push @outrefs, $just_svs ? $egv :
-            Devel::MAT::SV::Reference( "the egv", ( $egv_is_self ? "weak" : "strong" ) => $egv );
+         my $strength = $egv_is_self ? "weak" : "strong";
+         push @outrefs, $no_desc ? ( $strength => $egv ) :
+            Devel::MAT::SV::Reference( "the egv", $strength => $egv );
       }
    }
 
@@ -608,7 +611,7 @@ sub _outrefs
 
 package Devel::MAT::SV::SCALAR;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 2 );
 use constant $CONSTANTS;
 
@@ -755,12 +758,12 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my @outrefs;
 
    if( $match & STRENGTH_STRONG and my $ourstash = $self->ourstash ) {
-      push @outrefs, $just_svs ? $ourstash :
+      push @outrefs, $no_desc ? ( strong => $ourstash ) :
          Devel::MAT::SV::Reference( "the our stash", strong => $ourstash );
    }
 
@@ -769,7 +772,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REF;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 3 );
 use constant $CONSTANTS;
 
@@ -839,18 +842,19 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my @outrefs;
 
    my $is_weak = $self->is_weak;
    if( $match & ( $is_weak ? STRENGTH_WEAK : STRENGTH_STRONG ) and my $rv = $self->rv ) {
-      push @outrefs, $just_svs ? $rv :
-         Devel::MAT::SV::Reference( "the referrant", ( $self->is_weak ? "weak" : "strong" ), $rv );
+      my $strength = $is_weak ? "weak" : "strong";
+      push @outrefs, $no_desc ? ( $strength => $rv ) :
+         Devel::MAT::SV::Reference( "the referrant", $strength => $rv );
    }
 
    if( $match & STRENGTH_STRONG and my $ourstash = $self->ourstash ) {
-      push @outrefs, $just_svs ? $ourstash :
+      push @outrefs, $no_desc ? ( strong => $ourstash ) :
          Devel::MAT::SV::Reference( "the our stash", strong => $ourstash );
    }
 
@@ -859,7 +863,7 @@ sub _outrefs
 
 package Devel::MAT::SV::ARRAY;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 4 );
 use constant $CONSTANTS;
 
@@ -961,7 +965,7 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my $n = $self->n_elems;
 
@@ -972,7 +976,7 @@ sub _outrefs
          foreach my $idx ( 0 .. $n-1 ) {
             my $sv = $self->elem( $idx ) or next;
 
-            push @outrefs, $just_svs ? $sv :
+            push @outrefs, $no_desc ? ( weak => $sv ) :
                Devel::MAT::SV::Reference( "element " . Devel::MAT::Cmd->format_value( $idx, index => 1 ), weak => $sv );
          }
       }
@@ -981,13 +985,14 @@ sub _outrefs
       foreach my $idx ( 0 .. $n-1 ) {
          my $sv = $self->elem( $idx ) or next;
 
-         my $name = "element " . Devel::MAT::Cmd->format_value( $idx, index => 1 );
+         my $name = $no_desc ? undef :
+            "element " . Devel::MAT::Cmd->format_value( $idx, index => 1 );
          if( $match & STRENGTH_STRONG ) {
-            push @outrefs, $just_svs ? $sv :
+            push @outrefs, $no_desc ? ( strong => $sv ) :
                Devel::MAT::SV::Reference( $name, strong => $sv );
          }
          if( $match & STRENGTH_INDIRECT and $sv->type eq "REF" and !$sv->{magic} and my $rv = $sv->rv ) {
-            push @outrefs, $just_svs ? $rv :
+            push @outrefs, $no_desc ? ( indirect => $rv ) :
                Devel::MAT::SV::Reference( $name . " via RV", indirect => $rv );
          }
       }
@@ -999,7 +1004,7 @@ sub _outrefs
 package Devel::MAT::SV::PADLIST;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 use constant type => "PADLIST";
 use constant $CONSTANTS;
 
@@ -1021,7 +1026,7 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my @outrefs;
 
@@ -1030,14 +1035,14 @@ sub _outrefs
       my $n = $self->n_elems;
 
       if( my $padnames = $df->sv_at( $self->elem_at( 0 ) ) ) {
-         push @outrefs, $just_svs ? $padnames :
+         push @outrefs, $no_desc ? ( strong => $padnames ) :
             Devel::MAT::SV::Reference( "the padnames", strong => $padnames );
       }
 
       foreach my $idx ( 1 .. $n-1 ) {
          my $pad = $df->sv_at( $self->elem_at( $idx ) ) or next;
 
-         push @outrefs, $just_svs ? $pad :
+         push @outrefs, $no_desc ? ( strong => $pad ) :
             Devel::MAT::SV::Reference( "pad at depth $idx", strong => $pad );
       }
    }
@@ -1048,7 +1053,7 @@ sub _outrefs
 package Devel::MAT::SV::PADNAMES;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 use constant type => "PADNAMES";
 use constant $CONSTANTS;
 
@@ -1110,7 +1115,7 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my @outrefs;
 
@@ -1121,7 +1126,7 @@ sub _outrefs
       foreach my $idx ( 1 .. $n-1 ) {
          my $padname = $df->sv_at( $self->elem_at( $idx ) ) or next;
 
-         push @outrefs, $just_svs ? $padname :
+         push @outrefs, $no_desc ? ( strong => $padname ) :
             Devel::MAT::SV::Reference( "padname " . Devel::MAT::Cmd->format_value( $idx, index => 1 ), strong => $padname );
       }
    }
@@ -1132,7 +1137,7 @@ sub _outrefs
 package Devel::MAT::SV::PAD;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 use constant type => "PAD";
 use constant $CONSTANTS;
 
@@ -1182,7 +1187,7 @@ sub lexvars
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my $padcv = $self->padcv;
 
@@ -1191,28 +1196,31 @@ sub _outrefs
    my @outrefs;
 
    if( $match & STRENGTH_STRONG and my $argsav = $svs[0] ) {
-      push @outrefs, $just_svs ? $argsav :
+      push @outrefs, $no_desc ? ( strong => $argsav ) :
          Devel::MAT::SV::Reference( "the " . Devel::MAT::Cmd->format_note( '@_', 1 ) . " av", strong => $argsav );
    }
 
    foreach my $idx ( 1 .. $#svs ) {
       my $sv = $svs[$idx] or next;
 
-      my $padname = $padcv->padname( $idx );
-      my $name = $padname ? $padname->name : undef;
-      if( $name ) {
-         $name = "the lexical " . Devel::MAT::Cmd->format_note( $name, 1 );
-      }
-      else {
-         $name = "element " . Devel::MAT::Cmd->format_value( $idx, index => 1 );
+      my $name;
+      if( !$no_desc ) {
+         my $padname = $padcv->padname( $idx );
+         $name = $padname ? $padname->name : undef;
+         if( $name ) {
+            $name = "the lexical " . Devel::MAT::Cmd->format_note( $name, 1 );
+         }
+         else {
+            $name = "element " . Devel::MAT::Cmd->format_value( $idx, index => 1 );
+         }
       }
 
       if( $match & STRENGTH_STRONG ) {
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( $name, strong => $sv );
       }
       if( $match & STRENGTH_INDIRECT and $sv->type eq "REF" and !$sv->{magic} and my $rv = $sv->rv ) {
-         push @outrefs, $just_svs ? $rv :
+         push @outrefs, $no_desc ? ( indirect => $rv ) :
             Devel::MAT::SV::Reference( $name . " via RV", indirect => $rv );
       }
    }
@@ -1222,7 +1230,7 @@ sub _outrefs
 
 package Devel::MAT::SV::HASH;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 5 );
 use constant $CONSTANTS;
 
@@ -1333,7 +1341,7 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my $df = $self->df;
 
@@ -1344,20 +1352,20 @@ sub _outrefs
       # in the backrefs slot directly
       if( $backrefs->type eq "ARRAY" ) {
          if( $match & STRENGTH_STRONG ) {
-            push @outrefs, $just_svs ? $backrefs :
+            push @outrefs, $no_desc ? ( strong => $backrefs ) :
                Devel::MAT::SV::Reference( "the backrefs list", strong => $backrefs );
          }
 
          if( $match & STRENGTH_INDIRECT ) {
             foreach my $sv ( $self->backrefs->elems ) {
-               push @outrefs, $just_svs ? $sv :
+               push @outrefs, $no_desc ? ( indirect => $sv ) :
                   Devel::MAT::SV::Reference( "a backref", indirect => $sv );
             }
          }
       }
       else {
          if( $match & STRENGTH_WEAK ) {
-            push @outrefs, $just_svs ? $backrefs :
+            push @outrefs, $no_desc ? ( weak => $backrefs ) :
                Devel::MAT::SV::Reference( "a backref", weak => $backrefs );
          }
       }
@@ -1365,13 +1373,15 @@ sub _outrefs
 
    foreach my $key ( $self->keys ) {
       my $sv = $df->sv_at( $self->value_at( $key ) ) or next;
-      my $name = "value " . Devel::MAT::Cmd->format_value( $key, key => 1 );
+      my $name = $no_desc ? undef :
+         "value " . Devel::MAT::Cmd->format_value( $key, key => 1 );
+
       if( $match & STRENGTH_STRONG ) {
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( $name, strong => $sv );
       }
       if( $match & STRENGTH_INDIRECT and $sv->type eq "REF" and !$sv->{magic} and my $rv = $sv->rv ) {
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( indirect => $sv ) :
             Devel::MAT::SV::Reference( $name . " via RV", indirect => $rv );
       }
    }
@@ -1381,7 +1391,7 @@ sub _outrefs
 
 package Devel::MAT::SV::STASH;
 use base qw( Devel::MAT::SV::HASH );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 6 );
 use constant $CONSTANTS;
 
@@ -1493,25 +1503,25 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my @outrefs = $self->SUPER::_outrefs( @_ );
 
    if( $match & STRENGTH_STRONG ) {
       if( my $sv = $self->mro_linearall ) {
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( "the mro linear all HV",  strong => $sv );
       }
       if( my $sv = $self->mro_linearcurrent ) {
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( "the mro linear current", strong => $sv );
       }
       if( my $sv = $self->mro_nextmethod ) {
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( "the mro next::method",   strong => $sv );
       }
       if( my $sv = $self->mro_isa ) {
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( "the mro ISA cache",      strong => $sv );
       }
    }
@@ -1521,7 +1531,7 @@ sub _outrefs
 
 package Devel::MAT::SV::CODE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 7 );
 use constant $CONSTANTS;
 
@@ -1653,6 +1663,12 @@ sub _fixup
          }
       }
    }
+
+   if( $self->is_cloned and my $oproot = $self->oproot ) {
+      if( my $protosub = $df->{protosubs_by_oproot}{$oproot} ) {
+         $self->_set_protosub_at( $protosub->addr );
+      }
+   }
 }
 
 =head2 stash
@@ -1931,7 +1947,7 @@ sub desc
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my $pads = $self->{pads};
 
@@ -1943,62 +1959,66 @@ sub _outrefs
 
    my $is_weakoutside = $self->is_weakoutside;
    if( $match & ( $is_weakoutside ? STRENGTH_WEAK : STRENGTH_STRONG ) and my $scope = $self->scope ) {
-      push @outrefs, $just_svs ? $scope :
-         Devel::MAT::SV::Reference( "the scope", ( $is_weakoutside ? "weak" : "strong" ) => $scope );
+      my $strength = $is_weakoutside ? "weak" : "strong";
+      push @outrefs, $no_desc ? ( $strength => $scope ) :
+         Devel::MAT::SV::Reference( "the scope", $strength => $scope );
    }
 
    if( $match & STRENGTH_WEAK and my $stash = $self->stash ) {
-      push @outrefs, $just_svs ? $stash :
+      push @outrefs, $no_desc ? ( weak => $stash ) :
          Devel::MAT::SV::Reference( "the stash", weak => $stash );
    }
 
    my $is_strong_gv = $self->is_cvgv_rc;
    if( $match & ( $is_strong_gv ? STRENGTH_STRONG : STRENGTH_WEAK ) and my $glob = $self->glob ) {
-      push @outrefs, $just_svs ? $glob :
-         Devel::MAT::SV::Reference( "the glob", ( $is_strong_gv ? "strong" : "weak" ) => $glob );
+      my $strength = $is_strong_gv ? "strong" : "weak";
+      push @outrefs, $no_desc ? ( $strength => $glob ) :
+         Devel::MAT::SV::Reference( "the glob", $strength => $glob );
    }
 
    if( $match & STRENGTH_STRONG and my $constval = $self->constval ) {
-      push @outrefs, $just_svs ? $constval :
+      push @outrefs, $no_desc ? ( strong => $constval ) :
          Devel::MAT::SV::Reference( "the constant value", strong => $constval );
    }
 
    if( $match & STRENGTH_INFERRED and my $protosub = $self->protosub ) {
-      push @outrefs, $just_svs ? $protosub :
+      push @outrefs, $no_desc ? ( inferred => $protosub ) :
          Devel::MAT::SV::Reference( "the protosub", inferred => $protosub );
    }
 
    if( $match & STRENGTH_STRONG ) {
       foreach my $sv ( $self->constants ) {
          $sv or next;
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( "a constant", strong => $sv );
       }
       foreach my $sv ( $self->globrefs ) {
          $sv or next;
-         push @outrefs, $just_svs ? $sv :
+         push @outrefs, $no_desc ? ( strong => $sv ) :
             Devel::MAT::SV::Reference( "a referenced glob", strong => $sv );
       }
    }
 
    if( $match & STRENGTH_STRONG and $have_padlist ) {
-      push @outrefs, $just_svs ? $self->padlist :
+      push @outrefs, $no_desc ? ( strong => $self->padlist ) :
          Devel::MAT::SV::Reference( "the padlist", strong => $self->padlist );
    }
 
    # If we have a PADLIST then its contents are indirect; if not then they
    #   are direct strong
    if( $match & ( $have_padlist ? STRENGTH_INDIRECT : STRENGTH_STRONG ) ) {
+      my $strength = $have_padlist ? "indirect" : "strong";
+
       if( my $padnames = $self->padnames ) {
-         push @outrefs, $just_svs ? $padnames :
-            Devel::MAT::SV::Reference( "the padnames", ( $have_padlist ? "indirect" : "strong" ) => $padnames );
+         push @outrefs, $no_desc ? ( $strength => $padnames ) :
+            Devel::MAT::SV::Reference( "the padnames", $strength => $padnames );
       }
 
       foreach my $depth ( 1 .. $maxdepth ) {
          my $pad = $pads->[$depth-1] or next;
 
-         push @outrefs, $just_svs ? $pad :
-            Devel::MAT::SV::Reference( "pad at depth $depth", ( $have_padlist ? "indirect" : "strong" ) => $pad );
+         push @outrefs, $no_desc ? ( $strength => $pad ) :
+            Devel::MAT::SV::Reference( "pad at depth $depth", $strength => $pad );
       }
    }
 
@@ -2007,7 +2027,7 @@ sub _outrefs
 
 package Devel::MAT::SV::IO;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 8 );
 use constant $CONSTANTS;
 
@@ -2057,21 +2077,21 @@ sub desc { "IO()" }
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my @outrefs;
 
    if( $match & STRENGTH_STRONG ) {
       if( my $gv = $self->topgv ) {
-         push @outrefs, $just_svs ? $gv :
+         push @outrefs, $no_desc ? ( strong => $gv ) :
             Devel::MAT::SV::Reference( "the top GV",    strong => $gv );
       }
       if( my $gv = $self->formatgv ) {
-         push @outrefs, $just_svs ? $gv :
+         push @outrefs, $no_desc ? ( strong => $gv ) :
             Devel::MAT::SV::Reference( "the format GV", strong => $gv );
       }
       if( my $gv = $self->bottomgv ) {
-         push @outrefs, $just_svs ? $gv :
+         push @outrefs, $no_desc ? ( strong => $gv ) :
             Devel::MAT::SV::Reference( "the bottom GV", strong => $gv );
       }
    }
@@ -2081,7 +2101,7 @@ sub _outrefs
 
 package Devel::MAT::SV::LVALUE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 9 );
 use constant $CONSTANTS;
 
@@ -2108,12 +2128,12 @@ sub desc { "LVALUE()" }
 sub _outrefs
 {
    my $self = shift;
-   my ( $match, $just_svs ) = @_;
+   my ( $match, $no_desc ) = @_;
 
    my @outrefs;
 
    if( $match & STRENGTH_STRONG and my $sv = $self->target ) {
-      push @outrefs, $just_svs ? $sv :
+      push @outrefs, $no_desc ? ( strong => $sv ) :
          Devel::MAT::SV::Reference( "the target", strong => $sv );
    }
 
@@ -2122,7 +2142,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REGEXP;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 10 );
 
 sub load {}
@@ -2133,7 +2153,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::FORMAT;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 11 );
 
 sub load {}
@@ -2144,7 +2164,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::INVLIST;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 __PACKAGE__->register_type( 12 );
 
 sub load {}
