@@ -9,9 +9,10 @@ use strict;
 use warnings;
 use base qw( Devel::MAT::Tool );
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 use constant CMD => "callstack";
+use constant CMD_DESC => "Display the call stack";
 
 =head1 NAME
 
@@ -55,7 +56,7 @@ Prints details of the call stack, including arguments to functions.
 
 =cut
 
-sub run_cmd
+sub run
 {
    my $self = shift;
 
