@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2016-2017 -- leonerd@leonerd.org.uk
 
 package Devel::MAT::Tool::Identify;
 
@@ -10,19 +10,19 @@ use warnings;
 use base qw( Devel::MAT::Tool );
 use utf8;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
-use Getopt::Long qw( GetOptionsFromArray );
 use List::Util qw( pairs );
 use List::UtilsBy qw( nsort_by );
 
 use constant CMD => "identify";
+use constant CMD_DESC => "Identify an SV by its referrers";
 
 =encoding UTF-8
 
 =head1 NAME
 
-C<Devel::MAT::Tool::Identify> - identify an SV by its ancestry
+C<Devel::MAT::Tool::Identify> - identify an SV by its referrers
 
 =head1 DESCRIPTION
 
@@ -175,9 +175,25 @@ to the depth limit.
 
 =cut
 
-sub run_cmd
+use constant CMD_OPTS => (
+   depth    => { help => "maximum depth to recurse",
+                 type => "i",
+                 alias => "d",
+                 default => 10 },
+   weak     => { help => "include weak references" },
+   all      => { help => "include weak and indirect references",
+                 alias => "a" },
+   no_elide => { help => "don't elide REF, PAD and symbol structures",
+                 alias => "n" },
+);
+
+use constant CMD_ARGS_SV => 1;
+
+sub run
 {
    my $self = shift;
+   my %opts = %{ +shift };
+   my ( $sv ) = @_;
 
    # reset
    $next_id = "A";
@@ -186,16 +202,10 @@ sub run_cmd
 
    my $STRONG = 1;
    my $DIRECT = 1;
-   my $ELIDE  = 1;
+   my $ELIDE  = !$opts{no_elide};
 
-   GetOptionsFromArray( \@_,
-      'depth|d=i'  => \my $DEPTH,
-      'weak'       => sub { $STRONG = 0 },
-      'all'        => sub { $STRONG = 0; $DIRECT = 0 },
-      'no-elide|n' => sub { $ELIDE = 0; },
-   ) or return;
-
-   my $sv = $self->get_sv( $_[0] );
+   $STRONG = 0              if $opts{weak};
+   $STRONG = 0, $DIRECT = 0 if $opts{all};
 
    $self->pmat->load_tool( "Inrefs", progress => $self->{progress} );
 
@@ -204,7 +214,7 @@ sub run_cmd
    );
 
    walk_graph( $self->pmat->inref_graph( $sv,
-      depth => $DEPTH,
+      depth => $opts{depth},
       strong => $STRONG,
       direct => $DIRECT,
       elide  => $ELIDE,
