@@ -8,7 +8,7 @@ package Devel::MAT::Tool::Inrefs;
 use strict;
 use warnings;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 use List::Util qw( pairs );
 
@@ -18,6 +18,10 @@ my %STRENGTH_TO_IDX = (
    indirect => 2,
    inferred => 3,
 );
+use constant {
+   IDX_ROOTS => 4,
+   IDX_STACK => 5,
+};
 
 =head1 NAME
 
@@ -49,18 +53,13 @@ sub patch_inrefs
 
    my $progress = $args{progress};
 
-   # Performance optimisation since we don't care about the 'name' of any of
-   #   these outrefs
-   no warnings 'redefine';
-   local *Devel::MAT::Cmd::format_value = sub { "" };
-   local *Devel::MAT::Cmd::format_note  = sub { "" };
-
    my $heap_total = scalar $df->heap;
    my $count = 0;
    foreach my $sv ( $df->heap ) {
-      foreach my $ref ( $sv->outrefs ) {
-         my $refsv = $ref->sv;
-         push @{ $refsv->{tool_inrefs}[ $STRENGTH_TO_IDX{ $ref->strength } ] }, $sv->addr if !$refsv->immortal;
+      foreach ( pairs $sv->outrefs( "NO_DESC" ) ) {
+         my ( $strength, $refsv ) = @$_;
+
+         push @{ $refsv->{tool_inrefs}[ $STRENGTH_TO_IDX{ $strength } ] }, $sv->addr if !$refsv->immortal;
       }
 
       $count++;
@@ -68,6 +67,18 @@ sub patch_inrefs
          $count, $heap_total, 100*$count / $heap_total ) if $progress and ($count % 10000) == 0
    }
 
+   # Most SVs are not roots or on the stack. To save time later on we'll make
+   #   a note of those rare ones that are
+   foreach ( pairs $df->_roots ) {
+      my ( undef, $sv ) = @$_;
+      $sv->{tool_inrefs}[IDX_ROOTS]++;
+   }
+
+   foreach my $addr ( @{ $df->{stack_at} } ) { # TODO
+      my $sv = $df->sv_at( $addr ) or next;
+      $sv->{tool_inrefs}[IDX_STACK]++;
+   }
+
    $progress->() if $progress;
 }
 
@@ -110,7 +121,11 @@ C<outrefs_*> methods.
 sub Devel::MAT::SV::_inrefs
 {
    my $self = shift;
-   my ( $just_svs, @strengths ) = @_;
+   my ( @strengths ) = @_;
+
+   # In scalar context we don't need to return SVs or Reference instances,
+   #   just count them. This allows a lot of optimisations.
+   my $just_count = !wantarray;
 
    $self->{tool_inrefs} ||= [];
 
@@ -119,43 +134,56 @@ sub Devel::MAT::SV::_inrefs
    foreach my $strength ( @strengths ) {
       my %seen;
       foreach my $addr ( @{ $self->{tool_inrefs}[ $STRENGTH_TO_IDX{$strength} ] // [] } ) {
-         my $sv = $df->sv_at( $addr );
-
-         if( $just_svs ) {
-            push @inrefs, $sv;
+         if( $just_count ) {
+            push @inrefs, 1;
          }
          else {
             $seen{$addr}++ and next;
 
+            my $sv = $df->sv_at( $addr );
+
             push @inrefs, Devel::MAT::SV::Reference( $_->name, $_->strength, $sv )
                for grep { $_->strength eq $strength and $_->sv == $self } $sv->outrefs;
          }
       }
    }
 
-   foreach ( pairs $df->_roots ) {
-      my ( $name, $sv ) = @$_;
-      push @inrefs, $just_svs ? undef : Devel::MAT::SV::Reference( $name, strong => undef )
-         if defined $sv and $sv == $self;
+   if( $strengths[0] eq "strong" and $self->{tool_inrefs}[IDX_ROOTS] ) {
+      if( $just_count ) {
+         push @inrefs, ( 1 ) x $self->{tool_inrefs}[IDX_ROOTS];
+      }
+      else {
+         foreach ( pairs $df->_roots ) {
+            my ( $name, $sv ) = @$_;
+            push @inrefs, Devel::MAT::SV::Reference( $name, strong => undef )
+               if defined $sv and $sv == $self;
+         }
+      }
    }
 
-   foreach my $addr ( @{ $df->{stack_at} } ) { # TODO
-      next unless $addr == $self->addr;
+   if( $strengths[0] eq "strong" and $self->{tool_inrefs}[IDX_STACK] ) {
+      if( $just_count ) {
+         push @inrefs, ( 1 ) x $self->{tool_inrefs}[IDX_STACK];
+      }
+      else {
+         foreach my $addr ( @{ $df->{stack_at} } ) { # TODO
+            next unless $addr == $self->addr;
 
-      push @inrefs, $just_svs ? undef :
-         Devel::MAT::SV::Reference( "a value on the stack", strong => undef );
+            push @inrefs, Devel::MAT::SV::Reference( "a value on the stack", strong => undef );
+         }
+      }
    }
 
    return @inrefs;
 }
 
-sub Devel::MAT::SV::inrefs          { shift->_inrefs( !wantarray, qw( strong weak indirect inferred )) }
-
-sub Devel::MAT::SV::inrefs_strong   { shift->_inrefs( !wantarray, qw( strong      )) }
-sub Devel::MAT::SV::inrefs_weak     { shift->_inrefs( !wantarray, qw( weak        )) }
-sub Devel::MAT::SV::inrefs_direct   { shift->_inrefs( !wantarray, qw( strong weak )) }
-sub Devel::MAT::SV::inrefs_indirect { shift->_inrefs( !wantarray, qw( indirect    )) }
-sub Devel::MAT::SV::inrefs_inferred { shift->_inrefs( !wantarray, qw( inferred    )) }
+# If 'strong' is included in these lists it must be first
+sub Devel::MAT::SV::inrefs          { shift->_inrefs( qw( strong weak indirect inferred )) }
+sub Devel::MAT::SV::inrefs_strong   { shift->_inrefs( qw( strong      )) }
+sub Devel::MAT::SV::inrefs_weak     { shift->_inrefs( qw( weak        )) }
+sub Devel::MAT::SV::inrefs_direct   { shift->_inrefs( qw( strong weak )) }
+sub Devel::MAT::SV::inrefs_indirect { shift->_inrefs( qw( indirect    )) }
+sub Devel::MAT::SV::inrefs_inferred { shift->_inrefs( qw( inferred    )) }
 
 =head1 AUTHOR
 
