@@ -8,7 +8,7 @@ package Devel::MAT::Tool::Sizes;
 use strict;
 use warnings;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 use constant FOR_UI => 1;
 
@@ -225,8 +225,8 @@ By default, only the individual SV size is counted.
 =cut
 
 use constant CMD => "largest";
+use constant CMD_DESC => "Find the largest SVs by size";
 
-use Getopt::Long qw( GetOptionsFromArray );
 use List::UtilsBy qw( max_by );
 
 my %seen;
@@ -280,26 +280,32 @@ sub list_largest_svs
    }
 }
 
-sub run_cmd
+use constant CMD_OPTS => (
+   struct => { help => "count SVs by structural size" },
+   owned  => { help => "count SVs by owned size" },
+);
+
+sub run
 {
    my $self = shift;
+   my %opts = %{ +shift };
+
    my $df = $self->df;
 
    my $METRIC;
-
-   GetOptionsFromArray( \@_,
-      'struct' => sub { $METRIC = "structure" },
-      'owned'  => sub { $METRIC = "owned" },
-   ) or return;
+   $METRIC = "structure" if $opts{struct};
+   $METRIC = "owned"     if $opts{owned};
 
    my @svs = $df->heap;
 
    my $method = $METRIC ? "${METRIC}_size" : "size";
 
+   my $heap_total = scalar @svs;
    my $count = 0;
    foreach my $sv ( @svs ) {
       $count++;
-      $self->report_progress( sprintf "Calculating sizes (%d of %d)", $count, scalar @svs ) if $count % 1000 == 0;
+      $self->report_progress( sprintf "Calculating sizes in %d of %d (%.2f%%)",
+         $count, $heap_total, 100*$count / $heap_total ) if $count % 20000 == 0;
       $sv->$method;
    }
    $self->report_progress();
